import { FormGroup, FormControl, Validators } from '@angular/forms';
import { Component, Input, Inject } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material';

export type DialogMode =
  | { mode: 'makePrimary' }
  | { mode: 'delete'; name: string }
  | { mode: 'rename'; oldName: string }
  | { mode: 'create' };

@Component({
  selector: 'cse-course-details-dialog',
  templateUrl: './modify-plan-dialog.component.html',
})
export class ModifyPlanDialogComponent {
  public form: FormGroup;

  constructor(
    private dialogRef: MatDialogRef<ModifyPlanDialogComponent>,
    @Inject(MAT_DIALOG_DATA) public data: DialogMode,
  ) {
    const initialName = this.data.mode === 'rename' ? this.data.oldName : '';
    if (this.data.mode === 'rename' || this.data.mode === 'create') {
      this.form = new FormGroup({
        planName: new FormControl(initialName, Validators.required),
      });
    } else {
      this.form = new FormGroup({});
    }
  }

  onSubmit() {
    switch (this.data.mode) {
      case 'makePrimary':
      case 'delete': {
        this.dialogRef.close({ areYouSure: true });
        break;
      }
      case 'rename':
      case 'create': {
        const name = `${this.form.value.planName}`;
        this.dialogRef.close({ name });
        break;
      }
      default:
        this.dialogRef.close();
    }
  }

  onCancel() {
    this.dialogRef.close();
  }
}
